==> lightnovel_crawler-2.7.10-py3-none-any.whl: lncrawl/spiders/chinesefantasy.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
from ..utils.crawler import Crawler
from bs4 import BeautifulSoup
import requests
import re
import logging
import json

logger = logging.getLogger('CHINESE_FANTASY_NOVELS')


class ChineseFantasyNovels(Crawler):
    def read_novel_info(self):
        '''Get novel title, autor, cover etc'''
        if not self.novel_url.endswith('/'):
            self.novel_url += '/'
        # end if
        logger.debug('Visiting %s', self.novel_url)
        soup = self.get_soup(self.novel_url)

        self.novel_title = soup.select_one('.btitle h1').text
        logger.info('Novel title: %s', self.novel_title)

        self.novel_author = soup.select_one('.bookinfo .status').text
        logger.info('%s', self.novel_author)

        volumes = set([])
        for a in reversed(soup.select('dl.chapterlist a')):
            ch_title = a.text.strip()
            ch_id = [int(x) for x in re.findall('\d+', ch_title)]
            ch_id = ch_id[0] if len(ch_id) else len(self.chapters) + 1
            vol_id = 1 + len(self.chapters) // 100
            volumes.add(vol_id)
            self.chapters.append({
                'id': ch_id,
                'volume': vol_id,
                'title': ch_title,
                'url': self.absolute_url(a['href']),
            })
        # end def
        logger.debug(self.chapters)

        self.volumes = [{'id': x, 'title': ''} for x in volumes]
        logger.debug(self.volumes)

        logger.info('%d volumes and %d chapters found',
                    len(self.volumes), len(self.chapters))
    # end def

    def download_chapter_body(self, chapter):
        '''Download body of a single chapter and return as clean html format.'''
        logger.info('Downloading %s', chapter['url'])
        soup = self.get_soup(chapter['url'])
        content = soup.select_one('#BookText')
        content.select_one('.link').decompose()
        body = self.extract_contents(content)
        return '<p>' + '</p><p>'.join(body) + '</p'
    # end def
# end class

==> lightnovel_crawler-2.8.4-py3-none-any.whl: lncrawl/spiders/chinesefantasy.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
from ..utils.crawler import Crawler
from bs4 import BeautifulSoup
import requests
import re
import logging
import json

logger = logging.getLogger('CHINESE_FANTASY_NOVELS')


class ChineseFantasyNovels(Crawler):
    def read_novel_info(self):
        '''Get novel title, autor, cover etc'''
        if not self.novel_url.endswith('/'):
            self.novel_url += '/'
        # end if
        logger.debug('Visiting %s', self.novel_url)
        soup = self.get_soup(self.novel_url)

        self.novel_title = soup.select_one('.btitle h1').text
        logger.info('Novel title: %s', self.novel_title)

        self.novel_author = soup.select_one('.bookinfo .status').text
        logger.info('%s', self.novel_author)

        volumes = set([])
        for a in reversed(soup.select('dl.chapterlist a')):
            ch_title = a.text.strip()
            ch_id = [int(x) for x in re.findall(r'\d+', ch_title)]
            ch_id = ch_id[0] if len(ch_id) else len(self.chapters) + 1
            vol_id = 1 + len(self.chapters) // 100
            volumes.add(vol_id)
            self.chapters.append({
                'id': ch_id,
                'volume': vol_id,
                'title': ch_title,
                'url': self.absolute_url(a['href']),
            })
        # end def
        logger.debug(self.chapters)

        self.volumes = [{'id': x, 'title': ''} for x in volumes]
        logger.debug(self.volumes)

        logger.info('%d volumes and %d chapters found',
                    len(self.volumes), len(self.chapters))
    # end def

    def download_chapter_body(self, chapter):
        '''Download body of a single chapter and return as clean html format.'''
        logger.info('Downloading %s', chapter['url'])
        soup = self.get_soup(chapter['url'])
        content = soup.select_one('#BookText')
        content.select_one('.link').decompose()
        body = self.extract_contents(content)
        return '<p>' + '</p><p>'.join(body) + '</p'
    # end def
# end class
